@@ -5,7 +5,10 @@ import tkinter.font as font
 import os, threading, traceback
 from PIL import ImageTk, Image
 
-import search_video, format_display, download_video, set_up
+from .search_video import search_youtube_video
+from .format_display import FormatUtils
+from .download_video import YtDownloadFormat, audio_filetypes, DLUtils
+from .set_up import SetupFile
 
 
 #list to store the remembered photos
@@ -268,7 +271,7 @@ class NestedRadioButton():
             except:
                 path = video_download_thread.restart()
 
-            app.loading_page.check_running_thread(video_download_thread, app.download_finish_sc, [root, app.loading_page, self.page_found], "download", download_video.get_progress)
+            app.loading_page.check_running_thread(video_download_thread, app.download_finish_sc, [root, app.loading_page, self.page_found], "download", DLUtils.get_progress)
 
 
     #hides all the children of the current NestedRadioButton that are displayed on the screen
@@ -571,7 +574,7 @@ class Application(Frame):
 
                 #video title
                 video_title_font = font.Font(size = 12, weight="bold")
-                video_title_text = format_display.format_name(results[i]["title"])
+                video_title_text = FormatUtils.format_name(results[i]["title"])
                 video_title = Label(video_att_frame_lsts[i], text=video_title_text, justify="left", bg="white", font=video_title_font)
                 video_title.bind("<Button-1>", lambda event, prev_root = [self.result_frame, displayed_search_pages[page_num]], video=results[i], page_found = page_num: self.download_option_sc(prev_root,video, page_found))
                 video_title.pack(anchor="w")
@@ -583,7 +586,7 @@ class Application(Frame):
                 video_view_post.pack(anchor="w")
 
                 #uploader
-                uploader_text = format_display.format_name(results[i]["channel"]["name"])
+                uploader_text = FormatUtils.format_name(results[i]["channel"]["name"])
                 uploader = Label(video_att_frame_lsts[i], text=uploader_text, justify="left", bg="white", fg="#808080")
                 uploader.bind("<Button-1>", lambda event, prev_root = [self.result_frame, displayed_search_pages[page_num]], video=results[i], page_found = page_num: self.download_option_sc(prev_root,video, page_found))
                 uploader.pack(anchor="w")
@@ -692,7 +695,7 @@ class Application(Frame):
             search = entry
 
         #determines if the search entry is a link to a youtube video
-        valid_youtube_link = download_video.valid_yt_link(search)
+        valid_youtube_link = DLUtils.valid_yt_link(search)
 
         #creates the frame for the results if not created yet
         if (current_sc == "home"):
@@ -864,8 +867,8 @@ class Application(Frame):
                 link = video["link"]
                 time = video["duration"]
                 date_posted = video["publishedTime"]
-                title = format_display.format_name(video["title"])
-                uploader = format_display.format_name(video["channel"]["name"])
+                title = FormatUtils.format_name(video["title"])
+                uploader = FormatUtils.format_name(video["channel"]["name"])
 
                 video_att = {"key":key, "link":link, "time":time, "date posted":date_posted, "title":title, "uploader":uploader}
 
@@ -918,24 +921,24 @@ class Application(Frame):
             key = video_att["key"]
             link = video_att["link"]
             meta_data_thread
-            time = format_display.format_time(meta["duration"])
+            time = FormatUtils.format_time(meta["duration"])
             title = meta["title"]
             uploader = meta["uploader"]
-            date_posted = format_display.format_date(str(meta["upload_date"]))
-            video_attributes = {"Views":format_display.format_count(str(meta["view_count"]), '')}
+            date_posted = FormatUtils.format_date(str(meta["upload_date"]))
+            video_attributes = {"Views":FormatUtils.format_count(str(meta["view_count"]), '')}
 
             video = {"id": meta["id"], "link": link, "title": title, "channel": {"name": uploader}, "duration": time, "publishedTime": date_posted, "viewCount": {"text": video_attributes["Views"]}}
 
 
 
         try:
-            video_attributes["Likes"] = format_display.format_count(str(meta["like_count"]), '')
+            video_attributes["Likes"] = FormatUtils.format_count(str(meta["like_count"]), '')
         except:
             pass
 
         video_attributes["Duration"] = time
         video_attributes["Date Posted"] = date_posted
-        video_attributes["Uploader"] = format_display.format_name(uploader)
+        video_attributes["Uploader"] = FormatUtils.format_name(uploader)
         video_attributes["Link"] = link
 
         #create the heading for the download frame if the frame has just been created
@@ -964,7 +967,7 @@ class Application(Frame):
         img_h = 125
 
         #get the thumbnail for the selected video
-        resized_image = format_display.process_image(thumbnail, img_w, img_h)
+        resized_image = FormatUtils.process_image(thumbnail, img_w, img_h)
         photo_lst[f"d{key}"] = ImageTk.PhotoImage(resized_image)
         resized_image  = photo_lst[f"d{key}"]
 
@@ -1030,13 +1033,13 @@ class Application(Frame):
 
         #all the video formats for download
         download_formats = meta["formats"]
-        available_formats = download_video.get_available_formats(download_formats)
-        video_codes  = [download_video.YtDownloadFormat.mp4_144p.value, download_video.YtDownloadFormat.mp4_240p.value,
-                        download_video.YtDownloadFormat.mp4_360p.value, download_video.YtDownloadFormat.mp4_480p.value,
-                        download_video.YtDownloadFormat.mp4_720p.value, download_video.YtDownloadFormat.mp4_1080p.value,
-                        download_video.YtDownloadFormat.mp4_640x360.value, download_video.YtDownloadFormat.mp4_1280x720.value,
-                        download_video.YtDownloadFormat.gp3_176x144.value, download_video.YtDownloadFormat.gp3_320x240.value,
-                        download_video.YtDownloadFormat.flv.value]
+        available_formats = DLUtils.get_available_formats(download_formats)
+        video_codes  = [YtDownloadFormat.mp4_144p.value, YtDownloadFormat.mp4_240p.value,
+                        YtDownloadFormat.mp4_360p.value, YtDownloadFormat.mp4_480p.value,
+                        YtDownloadFormat.mp4_720p.value, YtDownloadFormat.mp4_1080p.value,
+                        YtDownloadFormat.mp4_640x360.value, YtDownloadFormat.mp4_1280x720.value,
+                        YtDownloadFormat.gp3_176x144.value, YtDownloadFormat.gp3_320x240.value,
+                        YtDownloadFormat.flv.value]
 
         avail_video_formats = []
 
@@ -1045,10 +1048,10 @@ class Application(Frame):
             if (c in available_formats):
                 avail_video_formats.append(c)
 
-        video_formats = download_video.format_filetype(avail_video_formats)
+        video_formats = DLUtils.format_filetype(avail_video_formats)
 
         #audio formats to download video
-        available_audio_formats = {download_video.audio_filetypes["mp3"]:None, download_video.audio_filetypes["m4a"]:None, "ogg":None, download_video.audio_filetypes["aac"]:None, download_video.audio_filetypes["wav"]:None, "don't care":None}
+        available_audio_formats = {audio_filetypes["mp3"]:None, audio_filetypes["m4a"]:None, "ogg":None, audio_filetypes["aac"]:None, audio_filetypes["wav"]:None, "don't care":None}
         available_video_formats = {}
 
         for v in video_formats:
@@ -1089,7 +1092,7 @@ class Application(Frame):
 
     #copy video link to the clipboard in the download frame
     def copy_link(self, link):
-        format_display.copy_text(link)
+        FormatUtils.copy_text(link)
         messagebox.showinfo("Link Copied", "The link to the video has been successfully copied to the Clipboard")
 
 
@@ -1278,7 +1281,7 @@ class Application(Frame):
     #when the user changes the entry of the settings
     def entry_change_setting(self,entry_frame,key, entry, var):
         value = entry.get()
-        formatted_value = format_display.format_settings(key, value)
+        formatted_value = FormatUtils.format_settings(key, value)
         var.set(formatted_value)
         self.set_text(entry, formatted_value)
         entry_frame.config(bg="black")
@@ -1420,7 +1423,7 @@ class ProcessThread(threading.Thread):
 # search_videos(search_query, no_of_searches): Searches and formats the
 #   needed data for the videos results
 def search_videos(search_query: str, no_of_searches: int):
-    results = search_video.search_youtube_video(search_query, no_of_searches)
+    results = search_youtube_video(search_query, no_of_searches)
 
     #width and height of each image icon for the search results
     img_w = 150
@@ -1431,14 +1434,14 @@ def search_videos(search_query: str, no_of_searches: int):
     for i in range(result_len):
         thumbnails = results[i]["thumbnails"]
 
-        resized_image = format_display.process_image(thumbnails[-1]["url"], img_w, img_h)
-        format_display.load_image(resized_image, photo_lst, i)
+        resized_image = FormatUtils.process_image(thumbnails[-1]["url"], img_w, img_h)
+        FormatUtils.load_image(resized_image, photo_lst, i)
 
     return results
 
 
-# run(): Runs the main app
-def run():
+# run_main(): Runs the main app
+def run_main():
     if (root is not None):
         root.config(menu=menu_bar, bg="white")
 
@@ -1459,7 +1462,7 @@ if (__name__ != "__main__"):
 
 
     #read the data from the setup file
-    setting_file = set_up.SetupFile("setup.txt", os.getcwd())
+    setting_file = SetupFile("setup.txt", os.getcwd())
     setting_data = setting_file.get_data()
 
     #create the root window for the app
@@ -1475,9 +1478,9 @@ if (__name__ != "__main__"):
 
     #threads to search, download, or get meta data from videos
     search_wrap_thread = threading.Thread(target=word_wrap.wrap_search_text, args=[])
-    video_download_thread = ProcessThread(target=download_video.prepare_download, args=[None, None, None], key="download", return_value=True)
+    video_download_thread = ProcessThread(target=DLUtils.prepare_download, args=[None, None, None], key="download", return_value=True)
     search_video_thread = ProcessThread(target=search_videos, args=[None, None], key="search", return_value=True)
-    meta_data_thread = ProcessThread(target=download_video.get_metadata, args=[None], key="meta", return_value=True)
+    meta_data_thread = ProcessThread(target=DLUtils.get_metadata, args=[None], key="meta", return_value=True)
     video_download_thread.daemon = True
     search_video_thread.daemon = True
     meta_data_thread.daemon = True
